==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebTabComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescriptionMetadata } from "./WebTabDescriptionMetadata";
import { WebTabComponentEventArgsDescription } from "./WebTabComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebTabComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabComponentEventArgsDescriptionMetadata.a == null) {
                WebTabComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabComponentEventArgsDescriptionMetadata.c(WebTabComponentEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebTabComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTabComponentEventArgsDescriptionMetadata.a);
            WebTabDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabComponentEventArgs");
            a.item("Detail", "ExportedType:WebTab");
        }
        static d(a) {
            WebTabComponentEventArgsDescriptionMetadata.b(a);
            a.aa("WebTabComponentEventArgs", () => new WebTabComponentEventArgsDescription());
            a.z("WebTabComponentEventArgs", WebTabComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebTabComponentEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabComponentEventArgsDescriptionMetadata, 'WebTabComponentEventArgsDescriptionMetadata');
    WebTabComponentEventArgsDescriptionMetadata.a = null;
    return WebTabComponentEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebTabComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescriptionMetadata } from "./WebTabDescriptionMetadata";
import { WebTabComponentEventArgsDescription } from "./WebTabComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebTabComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabComponentEventArgsDescriptionMetadata.a == null) {
                WebTabComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabComponentEventArgsDescriptionMetadata.c(WebTabComponentEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebTabComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebTabComponentEventArgsDescriptionMetadata.a);
            WebTabDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabComponentEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "ExportedType:WebTab");
        }
        static d(a) {
            WebTabComponentEventArgsDescriptionMetadata.b(a);
            a.ac("WebTabComponentEventArgs", () => new WebTabComponentEventArgsDescription());
            a.ab("WebTabComponentEventArgs", WebTabComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebTabComponentEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabComponentEventArgsDescriptionMetadata, 'WebTabComponentEventArgsDescriptionMetadata');
    WebTabComponentEventArgsDescriptionMetadata.a = null;
    return WebTabComponentEventArgsDescriptionMetadata;
})();
